@@ -38,6 +38,7 @@ class CustomMutuallyExclusiveGroup(argparse._MutuallyExclusiveGroup):
     A subclass of argparse._MutuallyExclusiveGroup that determines whether
     the added args should go into the static of dynamic API
     """
+
     def add_argument(self, *args, **kwargs):
         if not self._container.finished_static_api:
             if (not self._container.in_context
@@ -65,6 +66,7 @@ class CustomParser(argparse.ArgumentParser):
     manager, only after this has happened, other arguments can be added using
     parser.add_argument.
     """
+
     def __init__(self, *args, **kwargs):
         self.DEFAULT_ENTRY_POINT = default.try_to_find_entry_point()
 
@@ -125,6 +127,9 @@ class CustomParser(argparse.ArgumentParser):
                            'Use --entry-point/-e to pass a '
                            'entry point\'s location or '
                            'place it in a standard location.\n\n'
+                           'Otherwise check if your pipeline have '
+                           '.yml as extension, '
+                           'change it to .yaml instead.\n\n'
                            'Need help? https://ploomber.io/community')
 
             return self.DEFAULT_ENTRY_POINT
